@@ -50,7 +50,7 @@
 #define YYSKELETON_NAME "yacc.c"
 
 /* Pure parsers.  */
-#define YYPURE 0
+#define YYPURE 2
 
 /* Push parsers.  */
 #define YYPUSH 0
@@ -66,37 +66,28 @@
 #define yydebug         constexpYYdebug
 #define yynerrs         constexpYYnerrs
 
-#define yylval          constexpYYlval
-#define yychar          constexpYYchar
 
 /* Copy the first part of user declarations.  */
-
+#line 19 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:339  */
 
 
 #include "cppvalue.h"
-#include "constexp.h"
+#include "constexp_p.h"
 #include "message.h"
 
-#if defined(_MSC_VER)
-#define MSDOS
-#endif
-
-#define YYSTYPE CPPValue
-
 #include <stdio.h>
 #include <stdlib.h>
 
-int constexpYYerror(const char *s)
+int constexpYYerror(yyscan_t yyscanner, const char *s)
 {
-  warn(g_constExpFileName,g_constExpLineNr,
-       "preprocessing issue while doing constant expression evaluation: %s",s);
+  struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
+  warn(yyextra->constExpFileName, yyextra->constExpLineNr,
+       "preprocessing issue while doing constant expression evaluation: %s: input='%s'",s,yyextra->inputString);
   return 0;
 }
 
-int constexpYYlex();
-
-
 
+#line 91 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -116,8 +107,8 @@ int constexpYYlex();
 
 /* In a future release of Bison, this section will be replaced
    by #include "ce_parse.hpp".  */
-#ifndef YY_CONSTEXPYY_CYGDRIVE_D_DAVE_LINUX_CYGWIN_CYGWIN_AUTO_MAINTAINER_DOXYGEN_DOXYGEN_1_8_11_2_I686_BUILD_GENERATED_SRC_CE_PARSE_HPP_INCLUDED
-# define YY_CONSTEXPYY_CYGDRIVE_D_DAVE_LINUX_CYGWIN_CYGWIN_AUTO_MAINTAINER_DOXYGEN_DOXYGEN_1_8_11_2_I686_BUILD_GENERATED_SRC_CE_PARSE_HPP_INCLUDED
+#ifndef YY_CONSTEXPYY_HOME_KBROWN_SRC_CYGPACKAGES_DOXYGEN_DOXYGEN_1_9_1_1_X86_64_BUILD_GENERATED_SRC_CE_PARSE_HPP_INCLUDED
+# define YY_CONSTEXPYY_HOME_KBROWN_SRC_CYGPACKAGES_DOXYGEN_DOXYGEN_1_9_1_1_X86_64_BUILD_GENERATED_SRC_CE_PARSE_HPP_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -171,15 +162,14 @@ typedef int YYSTYPE;
 #endif
 
 
-extern YYSTYPE constexpYYlval;
 
-int constexpYYparse (void);
+int constexpYYparse (yyscan_t yyscanner);
 
-#endif /* !YY_CONSTEXPYY_CYGDRIVE_D_DAVE_LINUX_CYGWIN_CYGWIN_AUTO_MAINTAINER_DOXYGEN_DOXYGEN_1_8_11_2_I686_BUILD_GENERATED_SRC_CE_PARSE_HPP_INCLUDED  */
+#endif /* !YY_CONSTEXPYY_HOME_KBROWN_SRC_CYGPACKAGES_DOXYGEN_DOXYGEN_1_9_1_1_X86_64_BUILD_GENERATED_SRC_CE_PARSE_HPP_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
+#line 173 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -479,11 +469,11 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,    77,    77,    81,    83,    92,    94,   100,   102,   108,
-     110,   117,   119,   125,   127,   133,   135,   139,   145,   147,
-     151,   155,   160,   167,   169,   173,   179,   181,   192,   205,
-     207,   218,   231,   239,   241,   243,   250,   254,   260,   262,
-     266,   268,   270,   272,   274
+       0,    75,    75,    82,    84,    93,    95,   101,   103,   109,
+     111,   118,   120,   126,   128,   134,   136,   140,   146,   148,
+     152,   156,   161,   168,   170,   174,   180,   182,   193,   206,
+     208,   219,   232,   240,   242,   244,   251,   255,   261,   263,
+     267,   272,   277,   282,   287
 };
 #endif
 
@@ -657,7 +647,7 @@ do                                                              \
     }                                                           \
   else                                                          \
     {                                                           \
-      yyerror (YY_("syntax error: cannot back up")); \
+      yyerror (yyscanner, YY_("syntax error: cannot back up")); \
       YYERROR;                                                  \
     }                                                           \
 while (0)
@@ -694,7 +684,7 @@ do {                                                                      \
     {                                                                     \
       YYFPRINTF (stderr, "%s ", Title);                                   \
       yy_symbol_print (stderr,                                            \
-                  Type, Value); \
+                  Type, Value, yyscanner); \
       YYFPRINTF (stderr, "\n");                                           \
     }                                                                     \
 } while (0)
@@ -705,10 +695,11 @@ do {                                                                      \
 `----------------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner)
 {
   FILE *yyo = yyoutput;
   YYUSE (yyo);
+  YYUSE (yyscanner);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -724,12 +715,12 @@ yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvalue
 `--------------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner)
 {
   YYFPRINTF (yyoutput, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
+  yy_symbol_value_print (yyoutput, yytype, yyvaluep, yyscanner);
   YYFPRINTF (yyoutput, ")");
 }
 
@@ -762,7 +753,7 @@ do {                                                            \
 `------------------------------------------------*/
 
 static void
-yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
+yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, yyscan_t yyscanner)
 {
   unsigned long int yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
@@ -776,7 +767,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
                        &(yyvsp[(yyi + 1) - (yynrhs)])
-                                              );
+                                              , yyscanner);
       YYFPRINTF (stderr, "\n");
     }
 }
@@ -784,7 +775,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
 # define YY_REDUCE_PRINT(Rule)          \
 do {                                    \
   if (yydebug)                          \
-    yy_reduce_print (yyssp, yyvsp, Rule); \
+    yy_reduce_print (yyssp, yyvsp, Rule, yyscanner); \
 } while (0)
 
 /* Nonzero means print parse trace.  It is left uninitialized so that
@@ -1042,9 +1033,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 `-----------------------------------------------*/
 
 static void
-yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, yyscan_t yyscanner)
 {
   YYUSE (yyvaluep);
+  YYUSE (yyscanner);
   if (!yymsg)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
@@ -1057,22 +1049,26 @@ yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
 
 
 
-/* The lookahead symbol.  */
-int yychar;
-
-/* The semantic value of the lookahead symbol.  */
-YYSTYPE yylval;
-/* Number of syntax errors so far.  */
-int yynerrs;
-
-
 /*----------.
 | yyparse.  |
 `----------*/
 
 int
-yyparse (void)
+yyparse (yyscan_t yyscanner)
 {
+/* The lookahead symbol.  */
+int yychar;
+
+
+/* The semantic value of the lookahead symbol.  */
+/* Default value used for initialization, for pacifying older GCCs
+   or non-GCC compilers.  */
+YY_INITIAL_VALUE (static YYSTYPE yyval_default;)
+YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
+
+    /* Number of syntax errors so far.  */
+    int yynerrs;
+
     int yystate;
     /* Number of tokens to shift before error messages enabled.  */
     int yyerrstatus;
@@ -1227,7 +1223,7 @@ yybackup:
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
-      yychar = yylex ();
+      yychar = yylex (&yylval, yyscanner);
     }
 
   if (yychar <= YYEOF)
@@ -1306,186 +1302,189 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-
-    { g_resultValue = (yyvsp[0]); return 0; }
-
+#line 76 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
+    {
+         struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
+         yyextra->resultValue = (yyvsp[0]); return 0;
+       }
+#line 1311 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 3:
-
+#line 83 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1317 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 4:
-
+#line 87 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 		       bool c = ((yyvsp[-4]).isInt() ? ((long)(yyvsp[-4]) != 0) : ((double)(yyvsp[-4]) != 0.0));
 		       (yyval) = c ? (yyvsp[-2]) : (yyvsp[0]);
 	             }
-
+#line 1326 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 5:
-
+#line 94 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1332 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 6:
-
+#line 96 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 			 (yyval) = CPPValue( (long)((long)(yyvsp[-2]) || (long)(yyvsp[0])) );
 		       }
-
+#line 1340 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 7:
-
+#line 102 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1346 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 8:
-
+#line 104 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 			  (yyval) = CPPValue( (long)((long)(yyvsp[-2]) && (long)(yyvsp[0])) );
 			}
-
+#line 1354 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 9:
-
+#line 110 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1360 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 10:
-
+#line 113 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { 
 			   (yyval) = CPPValue( (long)(yyvsp[-2]) | (long)(yyvsp[0]) );
 			 }
-
+#line 1368 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 11:
-
+#line 119 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1374 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 12:
-
+#line 121 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 			   (yyval) = CPPValue( (long)(yyvsp[-2]) ^ (long)(yyvsp[0]) );
 			 }
-
+#line 1382 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 13:
-
+#line 127 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1388 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 14:
-
+#line 129 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { 
 		  (yyval) = CPPValue( (long)(yyvsp[-2]) & (long)(yyvsp[0]) );
 		}
-
+#line 1396 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 15:
-
+#line 135 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1402 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 16:
-
+#line 137 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { 
 		       (yyval) = CPPValue( (long)((double)(yyvsp[-2]) == (double)(yyvsp[0])) );
 	             }
-
+#line 1410 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 17:
-
+#line 141 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
                        (yyval) = CPPValue( (long)((double)(yyvsp[-2]) != (double)(yyvsp[0])) );
 		     }
-
+#line 1418 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 18:
-
+#line 147 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1424 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 19:
-
+#line 149 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { 
 			 (yyval) = CPPValue( (long)((double)(yyvsp[-2]) < (double)(yyvsp[0])) );
 		       }
-
+#line 1432 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 20:
-
+#line 153 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
                          (yyval) = CPPValue( (long)((double)(yyvsp[-2]) > (double)(yyvsp[0])) );
 		       }
-
+#line 1440 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 21:
-
+#line 158 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 		         (yyval) = CPPValue( (long)((double)(yyvsp[-2]) <= (double)(yyvsp[0])) );
 		       }
-
+#line 1448 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 22:
-
+#line 163 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 			 (yyval) = CPPValue( (long)((double)(yyvsp[-2]) >= (double)(yyvsp[0])) );
 		       }
-
+#line 1456 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 23:
-
+#line 169 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1462 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 24:
-
+#line 171 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 		    (yyval) = CPPValue( (long)(yyvsp[-2]) << (long)(yyvsp[0]) );	
 		  }
-
+#line 1470 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 25:
-
+#line 175 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 		    (yyval) = CPPValue( (long)(yyvsp[-2]) >> (long)(yyvsp[0]) );
 		  }
-
+#line 1478 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 26:
-
+#line 181 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1484 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 27:
-
+#line 183 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 		       if (!(yyvsp[-2]).isInt() || !(yyvsp[0]).isInt())
 		       {
@@ -1496,11 +1495,11 @@ yyreduce:
 		         (yyval) = CPPValue( (long)(yyvsp[-2]) + (long)(yyvsp[0]) );
 		       }
 		     }
-
+#line 1499 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 28:
-
+#line 194 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 		       if (!(yyvsp[-2]).isInt() || !(yyvsp[0]).isInt())
 		       {
@@ -1511,17 +1510,17 @@ yyreduce:
 		         (yyval) = CPPValue( (long)(yyvsp[-2]) - (long)(yyvsp[0]) );
 		       }
 		     }
-
+#line 1514 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 29:
-
+#line 207 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1520 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 30:
-
+#line 209 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { 
 			     if (!(yyvsp[-2]).isInt() || !(yyvsp[0]).isInt())
 			     {
@@ -1532,11 +1531,11 @@ yyreduce:
 			       (yyval) = CPPValue( (long)(yyvsp[-2]) * (long)(yyvsp[0]) );
 			     }
 			   }
-
+#line 1535 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 31:
-
+#line 220 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { 
 			     if (!(yyvsp[-2]).isInt() || !(yyvsp[0]).isInt())
 			     {
@@ -1549,102 +1548,117 @@ yyreduce:
 			       (yyval) = CPPValue( (long)(yyvsp[-2]) / value );
 			     }
 			   }
-
+#line 1552 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 32:
-
+#line 233 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { 
 			     long value = (yyvsp[0]);
 			     if (value==0) value=1;
 			     (yyval) = CPPValue( (long)(yyvsp[-2]) % value );
 			   }
-
+#line 1562 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 33:
-
+#line 241 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1568 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 34:
-
+#line 243 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[-1]); }
-
+#line 1574 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 35:
-
+#line 245 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { 
 		    if ((yyvsp[0]).isInt()) 
                       (yyval) = CPPValue(-(long)(yyvsp[0]));
                     else
 		      (yyval) = CPPValue(-(double)(yyvsp[0]));
 		  }
-
+#line 1585 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 36:
-
+#line 252 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 		    (yyval) = CPPValue(~(long)(yyvsp[0]));
 		  }
-
+#line 1593 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 37:
-
+#line 256 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     {
 		    (yyval) = CPPValue((long)!(long)(yyvsp[0]));
 		  }
-
+#line 1601 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 38:
-
+#line 262 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[0]); }
-
+#line 1607 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 39:
-
+#line 264 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
     { (yyval) = (yyvsp[-1]); }
-
+#line 1613 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 40:
-
-    { (yyval) = parseOctal(); }
-
+#line 268 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
+    {
+	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
+	    (yyval) = parseOctal(yyextra->strToken);
+	  }
+#line 1622 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 41:
-
-    { (yyval) = parseDecimal(); }
-
+#line 273 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
+    {
+	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
+	    (yyval) = parseDecimal(yyextra->strToken);
+	  }
+#line 1631 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 42:
-
-    { (yyval) = parseHexadecimal(); }
-
+#line 278 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
+    {
+	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
+	    (yyval) = parseHexadecimal(yyextra->strToken);
+	  }
+#line 1640 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 43:
-
-    { (yyval) = parseCharacter(); }
-
+#line 283 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
+    {
+	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
+	    (yyval) = parseCharacter(yyextra->strToken);
+	  }
+#line 1649 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
   case 44:
-
-    { (yyval) = parseFloat(); }
-
+#line 288 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1646  */
+    {
+	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
+	    (yyval) = parseFloat(yyextra->strToken);
+	  }
+#line 1658 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
     break;
 
 
-
+#line 1662 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/build/generated_src/ce_parse.cpp" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1694,7 +1708,7 @@ yyerrlab:
     {
       ++yynerrs;
 #if ! YYERROR_VERBOSE
-      yyerror (YY_("syntax error"));
+      yyerror (yyscanner, YY_("syntax error"));
 #else
 # define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                         yyssp, yytoken)
@@ -1721,7 +1735,7 @@ yyerrlab:
                 yymsgp = yymsg;
               }
           }
-        yyerror (yymsgp);
+        yyerror (yyscanner, yymsgp);
         if (yysyntax_error_status == 2)
           goto yyexhaustedlab;
       }
@@ -1745,7 +1759,7 @@ yyerrlab:
       else
         {
           yydestruct ("Error: discarding",
-                      yytoken, &yylval);
+                      yytoken, &yylval, yyscanner);
           yychar = YYEMPTY;
         }
     }
@@ -1801,7 +1815,7 @@ yyerrlab1:
 
 
       yydestruct ("Error: popping",
-                  yystos[yystate], yyvsp);
+                  yystos[yystate], yyvsp, yyscanner);
       YYPOPSTACK (1);
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
@@ -1838,7 +1852,7 @@ yyabortlab:
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
 yyexhaustedlab:
-  yyerror (YY_("memory exhausted"));
+  yyerror (yyscanner, YY_("memory exhausted"));
   yyresult = 2;
   /* Fall through.  */
 #endif
@@ -1850,7 +1864,7 @@ yyreturn:
          user semantic actions for why this is necessary.  */
       yytoken = YYTRANSLATE (yychar);
       yydestruct ("Cleanup: discarding lookahead",
-                  yytoken, &yylval);
+                  yytoken, &yylval, yyscanner);
     }
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYABORT or YYACCEPT.  */
@@ -1859,7 +1873,7 @@ yyreturn:
   while (yyssp != yyss)
     {
       yydestruct ("Cleanup: popping",
-                  yystos[*yyssp], yyvsp);
+                  yystos[*yyssp], yyvsp, yyscanner);
       YYPOPSTACK (1);
     }
 #ifndef yyoverflow
@@ -1872,5 +1886,5 @@ yyreturn:
 #endif
   return yyresult;
 }
-
+#line 294 "/home/kbrown/src/cygpackages/doxygen/doxygen-1.9.1-1.x86_64/src/doxygen/src/constexp.y" /* yacc.c:1906  */
 
